# coding: utf-8

"""
    Typewise API

    Typewise server for text completion, autocorrection and emoji searching.  # noqa: E501

    OpenAPI spec version: 0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import typewiseprediction
from typewiseprediction.models.single_completion_token_probability import SingleCompletionTokenProbability  # noqa: E501
from typewiseprediction.rest import ApiException


class TestSingleCompletionTokenProbability(unittest.TestCase):
    """SingleCompletionTokenProbability unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSingleCompletionTokenProbability(self):
        """Test SingleCompletionTokenProbability"""
        # FIXME: construct object with mandatory attributes with example values
        # model = typewiseprediction.models.single_completion_token_probability.SingleCompletionTokenProbability()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Typewise API

    Typewise server for text completion, autocorrection and emoji searching.  # noqa: E501

    OpenAPI spec version: 0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import typewiseprediction
from typewiseprediction.api.correction_api import CorrectionApi  # noqa: E501
from typewiseprediction.rest import ApiException


class TestCorrectionApi(unittest.TestCase):
    """CorrectionApi unit test stubs"""

    def setUp(self):
        self.api = CorrectionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_complete_correction_correction_whole_sentence_post(self):
        """Test case for complete_correction_correction_whole_sentence_post

        Complete Correction  # noqa: E501
        """
        pass

    def test_complete_correction_correction_whole_sentence_post_0(self):
        """Test case for complete_correction_correction_whole_sentence_post_0

        Complete Correction  # noqa: E501
        """
        pass

    def test_complete_correction_correction_whole_sentence_post_1(self):
        """Test case for complete_correction_correction_whole_sentence_post_1

        Complete Correction  # noqa: E501
        """
        pass

    def test_last_word_correction_correction_final_word_post(self):
        """Test case for last_word_correction_correction_final_word_post

        Last Word Correction  # noqa: E501
        """
        pass

    def test_last_word_correction_correction_final_word_post_0(self):
        """Test case for last_word_correction_correction_final_word_post_0

        Last Word Correction  # noqa: E501
        """
        pass

    def test_last_word_correction_correction_final_word_post_1(self):
        """Test case for last_word_correction_correction_final_word_post_1

        Last Word Correction  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Typewise API

    Typewise server for text completion, autocorrection and emoji searching.  # noqa: E501

    OpenAPI spec version: 0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CompletionRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'text': 'str',
        'correct_typo_in_partial_word': 'bool',
        'language': 'AllOfCompletionRequestLanguage',
        'max_number_of_predictions': 'int',
        'return_token_scores': 'bool'
    }

    attribute_map = {
        'text': 'text',
        'correct_typo_in_partial_word': 'correctTypoInPartialWord',
        'language': 'language',
        'max_number_of_predictions': 'maxNumberOfPredictions',
        'return_token_scores': 'returnTokenScores'
    }

    def __init__(self, text=None, correct_typo_in_partial_word=False, language=None, max_number_of_predictions=5, return_token_scores=False):  # noqa: E501
        """CompletionRequest - a model defined in Swagger"""  # noqa: E501
        self._text = None
        self._correct_typo_in_partial_word = None
        self._language = None
        self._max_number_of_predictions = None
        self._return_token_scores = None
        self.discriminator = None
        self.text = text
        if correct_typo_in_partial_word is not None:
            self.correct_typo_in_partial_word = correct_typo_in_partial_word
        if language is not None:
            self.language = language
        if max_number_of_predictions is not None:
            self.max_number_of_predictions = max_number_of_predictions
        if return_token_scores is not None:
            self.return_token_scores = return_token_scores

    @property
    def text(self):
        """Gets the text of this CompletionRequest.  # noqa: E501

        The input text to be autocompleted. If full next word prediction is required, end on a space.  # noqa: E501

        :return: The text of this CompletionRequest.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this CompletionRequest.

        The input text to be autocompleted. If full next word prediction is required, end on a space.  # noqa: E501

        :param text: The text of this CompletionRequest.  # noqa: E501
        :type: str
        """
        if text is None:
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def correct_typo_in_partial_word(self):
        """Gets the correct_typo_in_partial_word of this CompletionRequest.  # noqa: E501

        If true, don't constrain predictions to already typed characters, e.g. 'cahracte' can predict 'character', regardless of the typo.  # noqa: E501

        :return: The correct_typo_in_partial_word of this CompletionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._correct_typo_in_partial_word

    @correct_typo_in_partial_word.setter
    def correct_typo_in_partial_word(self, correct_typo_in_partial_word):
        """Sets the correct_typo_in_partial_word of this CompletionRequest.

        If true, don't constrain predictions to already typed characters, e.g. 'cahracte' can predict 'character', regardless of the typo.  # noqa: E501

        :param correct_typo_in_partial_word: The correct_typo_in_partial_word of this CompletionRequest.  # noqa: E501
        :type: bool
        """

        self._correct_typo_in_partial_word = correct_typo_in_partial_word

    @property
    def language(self):
        """Gets the language of this CompletionRequest.  # noqa: E501

        The language of the sentence.  # noqa: E501

        :return: The language of this CompletionRequest.  # noqa: E501
        :rtype: AllOfCompletionRequestLanguage
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this CompletionRequest.

        The language of the sentence.  # noqa: E501

        :param language: The language of this CompletionRequest.  # noqa: E501
        :type: AllOfCompletionRequestLanguage
        """

        self._language = language

    @property
    def max_number_of_predictions(self):
        """Gets the max_number_of_predictions of this CompletionRequest.  # noqa: E501

        The maximum number of predictions to return. The higher the number the slower the response time. Maximum 20.  # noqa: E501

        :return: The max_number_of_predictions of this CompletionRequest.  # noqa: E501
        :rtype: int
        """
        return self._max_number_of_predictions

    @max_number_of_predictions.setter
    def max_number_of_predictions(self, max_number_of_predictions):
        """Sets the max_number_of_predictions of this CompletionRequest.

        The maximum number of predictions to return. The higher the number the slower the response time. Maximum 20.  # noqa: E501

        :param max_number_of_predictions: The max_number_of_predictions of this CompletionRequest.  # noqa: E501
        :type: int
        """

        self._max_number_of_predictions = max_number_of_predictions

    @property
    def return_token_scores(self):
        """Gets the return_token_scores of this CompletionRequest.  # noqa: E501

        If true, also return the consituent token scores for each prediction.  # noqa: E501

        :return: The return_token_scores of this CompletionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._return_token_scores

    @return_token_scores.setter
    def return_token_scores(self, return_token_scores):
        """Sets the return_token_scores of this CompletionRequest.

        If true, also return the consituent token scores for each prediction.  # noqa: E501

        :param return_token_scores: The return_token_scores of this CompletionRequest.  # noqa: E501
        :type: bool
        """

        self._return_token_scores = return_token_scores

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CompletionRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompletionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Typewise API

    Typewise server for text completion, autocorrection and emoji searching.  # noqa: E501

    OpenAPI spec version: 0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SingleCompletion(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'text': 'str',
        'score': 'float',
        'completion_starting_index': 'int',
        'token_scores': 'list[SingleCompletionTokenProbability]'
    }

    attribute_map = {
        'text': 'text',
        'score': 'score',
        'completion_starting_index': 'completionStartingIndex',
        'token_scores': 'tokenScores'
    }

    def __init__(self, text=None, score=None, completion_starting_index=None, token_scores=None):  # noqa: E501
        """SingleCompletion - a model defined in Swagger"""  # noqa: E501
        self._text = None
        self._score = None
        self._completion_starting_index = None
        self._token_scores = None
        self.discriminator = None
        if text is not None:
            self.text = text
        self.score = score
        self.completion_starting_index = completion_starting_index
        if token_scores is not None:
            self.token_scores = token_scores

    @property
    def text(self):
        """Gets the text of this SingleCompletion.  # noqa: E501

        Predicted word.  # noqa: E501

        :return: The text of this SingleCompletion.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this SingleCompletion.

        Predicted word.  # noqa: E501

        :param text: The text of this SingleCompletion.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def score(self):
        """Gets the score of this SingleCompletion.  # noqa: E501

        For each candidate completion, the list of the scores returned by the inference. How the score is constructed depends on the inference technique of the model.  # noqa: E501

        :return: The score of this SingleCompletion.  # noqa: E501
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this SingleCompletion.

        For each candidate completion, the list of the scores returned by the inference. How the score is constructed depends on the inference technique of the model.  # noqa: E501

        :param score: The score of this SingleCompletion.  # noqa: E501
        :type: float
        """
        if score is None:
            raise ValueError("Invalid value for `score`, must not be `None`")  # noqa: E501

        self._score = score

    @property
    def completion_starting_index(self):
        """Gets the completion_starting_index of this SingleCompletion.  # noqa: E501

        Index (relative to the end) at which the completion starts. If input is 'this is a compl' and the predicted word is 'etion', then the index will be 0. If using feature correct_typo_in_partial_word, then 'this is a compl' will return 'completion' and the index will be -5.  # noqa: E501

        :return: The completion_starting_index of this SingleCompletion.  # noqa: E501
        :rtype: int
        """
        return self._completion_starting_index

    @completion_starting_index.setter
    def completion_starting_index(self, completion_starting_index):
        """Sets the completion_starting_index of this SingleCompletion.

        Index (relative to the end) at which the completion starts. If input is 'this is a compl' and the predicted word is 'etion', then the index will be 0. If using feature correct_typo_in_partial_word, then 'this is a compl' will return 'completion' and the index will be -5.  # noqa: E501

        :param completion_starting_index: The completion_starting_index of this SingleCompletion.  # noqa: E501
        :type: int
        """
        if completion_starting_index is None:
            raise ValueError("Invalid value for `completion_starting_index`, must not be `None`")  # noqa: E501

        self._completion_starting_index = completion_starting_index

    @property
    def token_scores(self):
        """Gets the token_scores of this SingleCompletion.  # noqa: E501

        Tokens and their corresponding probabilities for the current prediction.  # noqa: E501

        :return: The token_scores of this SingleCompletion.  # noqa: E501
        :rtype: list[SingleCompletionTokenProbability]
        """
        return self._token_scores

    @token_scores.setter
    def token_scores(self, token_scores):
        """Sets the token_scores of this SingleCompletion.

        Tokens and their corresponding probabilities for the current prediction.  # noqa: E501

        :param token_scores: The token_scores of this SingleCompletion.  # noqa: E501
        :type: list[SingleCompletionTokenProbability]
        """

        self._token_scores = token_scores

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SingleCompletion, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SingleCompletion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from typewiseprediction.api.completion_api import CompletionApi
from typewiseprediction.api.correction_api import CorrectionApi
from typewiseprediction.api.default_api import DefaultApi
from typewiseprediction.api.emoji_api import EmojiApi
from typewiseprediction.api.language_detection_api import LanguageDetectionApi



# coding: utf-8

# flake8: noqa
"""
    Typewise API

    Typewise server for text completion, autocorrection and emoji searching.  # noqa: E501

    OpenAPI spec version: 0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from typewiseprediction.models.all_of_complete_correction_request_sentence_keyboard import AllOfCompleteCorrectionRequestSentenceKeyboard
from typewiseprediction.models.all_of_complete_correction_request_sentence_language import AllOfCompleteCorrectionRequestSentenceLanguage
from typewiseprediction.models.all_of_completion_request_language import AllOfCompletionRequestLanguage
from typewiseprediction.models.all_of_last_word_correction_request_sentence_keyboard import AllOfLastWordCorrectionRequestSentenceKeyboard
from typewiseprediction.models.all_of_last_word_correction_request_sentence_language import AllOfLastWordCorrectionRequestSentenceLanguage
from typewiseprediction.models.complete_correction_reply import CompleteCorrectionReply
from typewiseprediction.models.complete_correction_request_sentence import CompleteCorrectionRequestSentence
from typewiseprediction.models.completion_reply import CompletionReply
from typewiseprediction.models.completion_request import CompletionRequest
from typewiseprediction.models.emoji_search_reply import EmojiSearchReply
from typewiseprediction.models.emoji_search_request import EmojiSearchRequest
from typewiseprediction.models.http_validation_error import HTTPValidationError
from typewiseprediction.models.keyboard import Keyboard
from typewiseprediction.models.language_detection_reply import LanguageDetectionReply
from typewiseprediction.models.language_detection_request import LanguageDetectionRequest
from typewiseprediction.models.last_word_correction_reply import LastWordCorrectionReply
from typewiseprediction.models.last_word_correction_request_sentence import LastWordCorrectionRequestSentence
from typewiseprediction.models.server_routes_completion_pydantic_models_language import ServerRoutesCompletionPydanticModelsLanguage
from typewiseprediction.models.server_routes_correction_pydantic_models_language import ServerRoutesCorrectionPydanticModelsLanguage
from typewiseprediction.models.server_routes_language_detection_pydantic_models_language import ServerRoutesLanguageDetectionPydanticModelsLanguage
from typewiseprediction.models.single_completion import SingleCompletion
from typewiseprediction.models.single_completion_token_probability import SingleCompletionTokenProbability
from typewiseprediction.models.single_language_prediction import SingleLanguagePrediction
from typewiseprediction.models.single_point_correction import SinglePointCorrection
from typewiseprediction.models.validation_error import ValidationError



# coding: utf-8

"""
    Typewise API

    Typewise server for text completion, autocorrection and emoji searching.  # noqa: E501

    OpenAPI spec version: 0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import typewiseprediction
from typewiseprediction.api.completion_api import CompletionApi  # noqa: E501
from typewiseprediction.rest import ApiException


class TestCompletionApi(unittest.TestCase):
    """CompletionApi unit test stubs"""

    def setUp(self):
        self.api = CompletionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_complete_completion_complete_post(self):
        """Test case for complete_completion_complete_post

        Complete  # noqa: E501
        """
        pass

    def test_complete_completion_complete_post_0(self):
        """Test case for complete_completion_complete_post_0

        Complete  # noqa: E501
        """
        pass

    def test_complete_completion_complete_post_1(self):
        """Test case for complete_completion_complete_post_1

        Complete  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
